@@ -1,16 +1,16 @@
 #' Network export configuration
 #'
-#' Network export configuration. This function only work within shiny or a web browser (not in RStudio)
+#' Network export configuration. This function only work within shiny or a web browser.
 #' 
 #'@param graph : a visNetwork object
-#'@param type : Type of export. One of "png" (default) or "jpeg"
+#'@param type : Type of export. One of "png" (default), "jpeg" or "pdf"
 #'@param name : name of imgage, default to "network"
-#'@param label : Label on button, default to "Export as png/jpeg"
+#'@param label : Label on button, default to "Export as png/jpeg/pdf"
 #'@param background : background color, default to white (#fff)
 #'@param float : button postion, default to "right" 
 #'@param style : button css style.
-#'@param loadDependencies / Boolean. TRUE by default. Load libraries for export (fileSaver, Blob, canvastoBlob,html2canvas)
-#'
+#'@param loadDependencies / Boolean. TRUE by default. Load libraries for export (fileSaver, Blob, canvastoBlob, html2canvas, jsPDF)
+#'@param ... : arguments for \link{addExport}
 #'
 #'@examples
 #'
@@ -28,27 +28,24 @@
 #'  visLegend()%>% visExport(type = "jpeg", name = "export-network", 
 #'    float = "left", label = "Save network", background = "purple", style= "") 
 #'  
-#'@seealso \link{visNodes} for nodes options, \link{visEdges} for edges options, \link{visGroups} for groups options, 
-#'\link{visLegend} for adding legend, \link{visOptions} for custom option, \link{visLayout} & \link{visHierarchicalLayout} for layout, 
-#'\link{visPhysics} for control physics, \link{visInteraction} for interaction, \link{visNetworkProxy} & \link{visFocus} & \link{visFit} for animation within shiny,
-#'\link{visDocumentation}, \link{visEvents}, \link{visConfigure} ...
+#'@seealso \link{visSave}
 #'
 #'@export
 #'@references See online documentation \url{http://datastorm-open.github.io/visNetwork/}
 visExport <- function(graph, type = "png", name = "network",
                          label = paste0("Export as ", type),
                          background = "#fff", float = "right", 
-                         style = NULL, loadDependencies = TRUE){
+                         style = NULL, loadDependencies = TRUE, ...){
   
   if(any(class(graph) %in% "visNetwork_Proxy")){
-    stop("Can't use visSetExport with visNetworkProxy object")
+    stop("Can't use visExport with visNetworkProxy object")
   }
   
   if(!any(class(graph) %in% "visNetwork")){
     stop("graph must be a visNetwork object")
   }
   
-  stopifnot(type%in%c("png", "jpeg"))
+  stopifnot(type%in%c("png", "jpeg", "pdf"))
   
   if(is.null(style)){
     css <- paste0("float:", float, 
@@ -73,7 +70,7 @@ visExport <- function(graph, type = "png", name = "network",
   graph$x$export <- export
   
   if(loadDependencies){
-    graph <- addExport(graph)
+    graph <- addExport(graph, ...)
   }
   
   graph
